@@ -46,6 +46,8 @@ sub probevars {
       my $self = shift;
       my $h = $self->SUPER::probevars;
       $h->{binary}{_example} = "/usr/local/sbin/fping6";
+      $h->{protocol}{_example} = "6";
+      $h->{protocol}{_default} = "6";
       $h->{sourceaddress}{_re} = "[0-9A-Fa-f:.]+";
       $h->{sourceaddress}{_example} = "::1";
       return $h;
